@@ -23,8 +23,10 @@
 #include <config.h>
 #endif
 
+#include <errno.h>
 #include <string.h>
 
+#include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
 #include <libedataserver/e-data-server-util.h>
@@ -42,7 +44,7 @@
 #define EXCHANGE_STOREINFO_VERSION 1
 
 /* Even if we are disconnected, we need to exchange_store_connect()
-   to get the offline data */
+ * to get the offline data */
 #define RETURN_VAL_IF_NOT_CONNECTED(store, cancellable, ex, val)\
 	if (!camel_exchange_store_connected (store, cancellable, NULL) && \
 	    !exchange_store_connect_sync (CAMEL_SERVICE (store), cancellable, ex)) \
@@ -86,16 +88,16 @@ make_folder_info (CamelExchangeStore *exch,
 	info->display_name = display_name;
 
 	/* Process the full-path and decode if required */
-	temp = strrchr (path+2, '/');
+	temp = strrchr (path + 2, '/');
 	if (temp) {
 		/* info->full_name should not have encoded path */
-		info->full_name = camel_url_decode_path (path+2);
+		info->full_name = camel_url_decode_path (path + 2);
 	} else {
 		/* If there are no sub-directories, decoded(name) will be
-		   equal to that of path+2.
-		   Ex: personal
+		 * equal to that of path+2.
+		 * Ex: personal
 		*/
-		info->full_name = g_strdup (path+2);
+		info->full_name = g_strdup (path + 2);
 	}
 	info->unread = unread_count;
 
@@ -114,6 +116,18 @@ make_folder_info (CamelExchangeStore *exch,
 	if ((flags & CAMEL_FOLDER_TYPE_MASK) == CAMEL_FOLDER_TYPE_SENT)
 		info->flags |= CAMEL_FOLDER_TYPE_SENT;
 
+	if ((flags & CAMEL_FOLDER_TYPE_MASK) == CAMEL_FOLDER_TYPE_CONTACTS)
+		info->flags |= CAMEL_FOLDER_TYPE_CONTACTS;
+
+	if ((flags & CAMEL_FOLDER_TYPE_MASK) == CAMEL_FOLDER_TYPE_EVENTS)
+		info->flags |= CAMEL_FOLDER_TYPE_EVENTS;
+
+	if ((flags & CAMEL_FOLDER_TYPE_MASK) == CAMEL_FOLDER_TYPE_MEMOS)
+		info->flags |= CAMEL_FOLDER_TYPE_MEMOS;
+
+	if ((flags & CAMEL_FOLDER_TYPE_MASK) == CAMEL_FOLDER_TYPE_TASKS)
+		info->flags |= CAMEL_FOLDER_TYPE_TASKS;
+
 	if (flags & CAMEL_FOLDER_SUBSCRIBED)
 		info->flags |= CAMEL_FOLDER_SUBSCRIBED;
 
@@ -229,6 +243,34 @@ exchange_store_path_to_physical (const gchar *prefix,
 	return ppath;
 }
 
+static void
+eex_migrate_to_user_cache_dir (CamelService *service)
+{
+	const gchar *user_data_dir, *user_cache_dir;
+
+	g_return_if_fail (service != NULL);
+	g_return_if_fail (CAMEL_IS_SERVICE (service));
+
+	user_data_dir = camel_service_get_user_data_dir (service);
+	user_cache_dir = camel_service_get_user_cache_dir (service);
+
+	g_return_if_fail (user_data_dir != NULL);
+	g_return_if_fail (user_cache_dir != NULL);
+
+	/* migrate only if the source directory exists and the destination doesn't */
+	if (g_file_test (user_data_dir, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR) &&
+	    !g_file_test (user_cache_dir, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
+		gchar *parent_dir;
+
+		parent_dir = g_path_get_dirname (user_cache_dir);
+		g_mkdir_with_parents (parent_dir, S_IRWXU);
+		g_free (parent_dir);
+
+		if (g_rename (user_data_dir, user_cache_dir) == -1)
+			g_debug ("%s: Failed to migrate '%s' to '%s': %s", G_STRFUNC, user_data_dir, user_cache_dir, g_strerror (errno));
+	}
+}
+
 static void
 exchange_store_finalize (GObject *object)
 {
@@ -261,9 +303,12 @@ exchange_store_constructed (GObject *object)
 		constructed (object);
 
 	service = CAMEL_SERVICE (object);
-	url = camel_service_get_camel_url (service);
+	eex_migrate_to_user_cache_dir (service);
 
+	url = camel_service_new_camel_url (service);
 	exch->base_url = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
+	camel_url_free (url);
+
 	/* Strip path */
 	p = strstr (exch->base_url, "//");
 	if (p) {
@@ -277,18 +322,23 @@ static gchar *
 exchange_store_get_name (CamelService *service,
                          gboolean brief)
 {
-	CamelURL *url;
+	CamelNetworkSettings *network_settings;
+	CamelSettings *settings;
+	const gchar *host;
+	const gchar *user;
 
-	url = camel_service_get_camel_url (service);
+	settings = camel_service_get_settings (service);
+
+	network_settings = CAMEL_NETWORK_SETTINGS (settings);
+	host = camel_network_settings_get_host (network_settings);
+	user = camel_network_settings_get_user (network_settings);
 
 	if (brief) {
 		return g_strdup_printf (
-			_("Exchange server %s"),
-			url->host);
+			_("Exchange server %s"), host);
 	} else {
 		return g_strdup_printf (
-			_("Exchange account for %s on %s"),
-			url->user, url->host);
+			_("Exchange account for %s on %s"), user, host);
 	}
 }
 
@@ -298,87 +348,22 @@ exchange_store_connect_sync (CamelService *service,
                              GError **error)
 {
 	CamelExchangeStore *exch = CAMEL_EXCHANGE_STORE (service);
-	gchar *password = NULL;
-	guint32 connect_status;
-	gboolean online_mode = FALSE;
 	CamelSession *session;
-	CamelURL *url;
-	GError *local_error = NULL;
+	gboolean success;
+
+	session = camel_service_get_session (service);
 
 	/* This lock is only needed for offline operation.
 	 * exchange_store_connect() is called many times in offline. */
 
 	g_mutex_lock (exch->connect_lock);
 
-	url = camel_service_get_camel_url (service);
-	session = camel_service_get_session (service);
-
-	online_mode = camel_session_get_online (session);
-
-	if (online_mode) {
-		if (!url->passwd) {
-			gchar *prompt;
-			guint32 prompt_flags = CAMEL_SESSION_PASSWORD_SECRET;
-
-			if (exch->reprompt_password)
-				prompt_flags |= CAMEL_SESSION_PASSWORD_REPROMPT;
-
-			prompt = camel_session_build_password_prompt (
-				"Exchange", url->user, url->host);
-
-			url->passwd = camel_session_get_password (
-				session, service, prompt,
-				"password", prompt_flags, error);
-
-			g_free (prompt);
-
-			exch->reprompt_password = url->passwd == NULL;
-		}
-
-		if (url->passwd == NULL) {
-			g_mutex_unlock (exch->connect_lock);
-			return FALSE;
-		}
-
-		password = url->passwd;
-	}
-
-	/* Initialize the stub connection */
-	if (!camel_exchange_utils_connect (service, password, &connect_status, &local_error)) {
-		g_clear_error (error);
-
-		/* The user cancelled the connection attempt. */
-		if (local_error == NULL)
-			g_set_error (
-				error, G_IO_ERROR,
-				G_IO_ERROR_CANCELLED,
-				"Cancelled");
-		else
-			g_propagate_error (error, local_error);
-		g_mutex_unlock (exch->connect_lock);
-		return FALSE;
-	}
-
-	if (!connect_status) {
-		exch->reprompt_password = TRUE;
-
-		if (url->passwd) {
-			g_free (url->passwd);
-			url->passwd = NULL;
-		}
-
-		g_clear_error (error);
-		g_set_error (
-			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
-			_("Could not authenticate to server. "
-			  "(Password incorrect?)"));
-		g_mutex_unlock (exch->connect_lock);
-		return FALSE;
-	}
+	success = camel_session_authenticate_sync (
+		session, service, NULL, cancellable, error);
 
 	g_mutex_unlock (exch->connect_lock);
 
-	return TRUE;
+	return success;
 }
 
 static gboolean
@@ -392,6 +377,52 @@ exchange_store_disconnect_sync (CamelService *service,
 	return TRUE;
 }
 
+static CamelAuthenticationResult
+exchange_store_authenticate_sync (CamelService *service,
+                                  const gchar *mechanism,
+                                  GCancellable *cancellable,
+                                  GError **error)
+{
+	const gchar *password;
+	guint32 connect_status;
+	GError *local_error = NULL;
+
+	/* XXX Oh man, this is the most broken backend I've seen yet.
+	 *     camel-exchange-utils.c uses CAMEL_ERROR_GENERIC for ALL
+	 *     errors, which effectively makes the GError useless since
+	 *     we can't distinguish between authentication rejections and
+	 *     other types of errors.  To be on the safe side, we assume
+	 *     all connection failures are authentication rejections, but
+	 *     that means the user may have to endure persistent password
+	 *     prompts when, for example, the server itself is offline.
+	 *     But that's been my experience with this backend all along.
+	 *     No wonder this thing has never really worked well...
+	 */
+
+	password = camel_service_get_password (service);
+	if (password == NULL) {
+		g_set_error_literal (
+			error, CAMEL_SERVICE_ERROR,
+			CAMEL_SERVICE_ERROR_CANT_AUTHENTICATE,
+			_("Authentication password not available"));
+		return CAMEL_AUTHENTICATION_ERROR;
+	}
+
+	camel_exchange_utils_connect (
+		service, password, &connect_status, &local_error);
+
+	/* XXX Leave a breadcrumb if the GError was set. */
+	if (local_error != NULL) {
+		g_warning ("%s: %s", G_STRFUNC, local_error->message);
+		g_error_free (local_error);
+	}
+
+	if (connect_status)
+		return CAMEL_AUTHENTICATION_ACCEPTED;
+	else
+		return CAMEL_AUTHENTICATION_REJECTED;
+}
+
 static GList *
 exchange_store_query_auth_types_sync (CamelService *service,
                                       GCancellable *cancellable,
@@ -438,20 +469,20 @@ exchange_store_get_folder_sync (CamelStore *store,
 	CamelExchangeStore *exch = CAMEL_EXCHANGE_STORE (store);
 	CamelService *service;
 	CamelFolder *folder;
-	const gchar *user_data_dir;
+	const gchar *user_cache_dir;
 	const gchar *short_name;
 	gchar *folder_dir;
 
 	RETURN_VAL_IF_NOT_CONNECTED (exch, cancellable, error, NULL);
 
 	service = CAMEL_SERVICE (store);
-	user_data_dir = camel_service_get_user_data_dir (service);
+	user_cache_dir = camel_service_get_user_cache_dir (service);
 
 	if (!folder_name || !*folder_name || g_ascii_strcasecmp (folder_name, "inbox") == 0)
 		folder_name = "personal/Inbox";
 
 	folder_dir = exchange_store_path_to_physical (
-		user_data_dir, folder_name);
+		user_cache_dir, folder_name);
 
 	if (!camel_exchange_store_connected (exch, cancellable, NULL)) {
 		if (!folder_dir || !g_file_test (folder_dir, G_FILE_TEST_IS_DIR)) {
@@ -798,6 +829,7 @@ camel_exchange_store_class_init (CamelExchangeStoreClass *class)
 	service_class->get_name = exchange_store_get_name;
 	service_class->connect_sync = exchange_store_connect_sync;
 	service_class->disconnect_sync = exchange_store_disconnect_sync;
+	service_class->authenticate_sync = exchange_store_authenticate_sync;
 	service_class->query_auth_types_sync = exchange_store_query_auth_types_sync;
 
 	store_class = CAMEL_STORE_CLASS (class);
@@ -827,6 +859,7 @@ camel_exchange_store_init (CamelExchangeStore *exch)
 	exch->folders_lock = g_mutex_new ();
 	exch->folders = g_hash_table_new (g_str_hash, g_str_equal);
 
+	store->flags |= CAMEL_STORE_USE_CACHE_DIR;
 	store->flags &= ~(CAMEL_STORE_VTRASH | CAMEL_STORE_VJUNK);
 	/* FIXME: Like the GroupWise provider, Exchange should also
 	have its own EXCAHNGE_JUNK flags so as to rightly handle
@@ -836,7 +869,7 @@ camel_exchange_store_init (CamelExchangeStore *exch)
 }
 
 /* Use this to ensure that the camel session is online and we are connected
-   too. Also returns the current status of the store */
+ * too. Also returns the current status of the store */
 gboolean
 camel_exchange_store_connected (CamelExchangeStore *store,
                                 GCancellable *cancellable,
@@ -862,7 +895,9 @@ camel_exchange_store_connected (CamelExchangeStore *store,
 }
 
 void
-camel_exchange_store_folder_created (CamelExchangeStore *estore, const gchar *name, const gchar *uri)
+camel_exchange_store_folder_created (CamelExchangeStore *estore,
+                                     const gchar *name,
+                                     const gchar *uri)
 {
 	CamelFolderInfo *info;
 
@@ -878,7 +913,9 @@ camel_exchange_store_folder_created (CamelExchangeStore *estore, const gchar *na
 }
 
 void
-camel_exchange_store_folder_deleted (CamelExchangeStore *estore, const gchar *name, const gchar *uri)
+camel_exchange_store_folder_deleted (CamelExchangeStore *estore,
+                                     const gchar *name,
+                                     const gchar *uri)
 {
 	CamelFolderInfo *info;
 	CamelFolder *folder;
