@@ -40,7 +40,7 @@
 #include "mail/em-account-editor.h"
 #include "mail/em-config.h"
 #include "libedataserver/e-account.h"
-#include "e-util/e-alert-dialog.h"
+#include "libevolution-utils/e-alert-dialog.h"
 
 #include "exchange-operations.h"
 #include "exchange-folder-size-display.h"
@@ -134,7 +134,9 @@ e_exchange_calendar_pcalendar_on_change (GtkTreeView *treeview,
 		return;
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
-	gtk_tree_selection_get_selected (selection, &model, &iter);
+	if (!selection ||
+	    !gtk_tree_selection_get_selected (selection, &model, &iter))
+		return;
 
 	gtk_tree_model_get (model, &iter, CALENDARRURI_COL, &ruri, -1);
 	es_ruri = g_strconcat (account->account_filename, "/;", ruri, NULL);
