@@ -45,7 +45,7 @@
 #include <e2k-utils.h>
 
 #include <e-util/e-dialog-utils.h>
-#include <e-util/e-alert-dialog.h>
+#include <libevolution-utils/e-alert-dialog.h>
 
 typedef struct {
 	const gchar *uri;
