@@ -42,7 +42,7 @@
 #include "exchange-operations.h"
 
 #include <e-util/e-dialog-utils.h>
-#include <e-util/e-alert-dialog.h>
+#include <libevolution-utils/e-alert-dialog.h>
 
 struct _ExchangePermissionsDialogPrivate {
 	ExchangeAccount *account;
